@@ -350,8 +350,19 @@ def _empty_name_callback():
 
 
 from i2.wrapper import rm_params
+from typing import Callable
 
-
+# TODO: Give control to ALL prepare_for_crude_dispatch arguments.
+#     param_to_mall_map: Optional[Union[dict, Iterable]] = None,
+#     mall: Optional[Mall] = None,
+#     include_stores_attribute: bool = False,
+#     output_store: Optional[Union[Mapping, str]] = None,
+#     # the arguments below only apply if output_store is given
+#     save_name_param: str = 'save_name',
+#     empty_name_callback: Callable[[], Any] = None,
+#     auto_namer: Callable[..., str] = None,
+#     output_trans: Callable[..., Any] = None,
+#     verbose: bool = True,
 def _crudified_func_nodes(
     var_nodes: Union[str, Iterable[str]],
     dag: DAG,
@@ -360,7 +371,9 @@ def _crudified_func_nodes(
     mall: Union[Mapping[str, Mapping[str, Any]], None] = None,
     include_stores_attribute: bool = False,
     save_name_param: str = 'save_name',
+    auto_namer: Callable[[], Any] = None,
     remove_save_name=True,  # TODO: should be False or not exist
+    store_factory=dict,
 ):
     if isinstance(var_nodes, str):
         var_nodes = var_nodes.split()
@@ -370,10 +383,20 @@ def _crudified_func_nodes(
         mall = defaultdict(dict)
 
     # TODO: This overwrites the mall outside so user is surprised!
-    mall = dict(
-        {var_node_name_to_store_name(var_name): dict() for var_name in var_nodes},
-        **mall,
-    )
+    # mall = dict(
+    #     {var_node_name_to_store_name(var_name): dict() for var_name in var_nodes},
+    #     **mall,
+    # )
+    # Possible solution:
+    for var_name in var_nodes:
+        store_name_for_var_name = var_node_name_to_store_name(var_name)
+        if store_name_for_var_name not in mall:
+            # TODO: store_factory has no args here. Maybe we want to use
+            #  call_forgivingly to allow user to specify how to make store according to
+            #  var_name or store_name_for_var_name (or not)
+            #  Other possibility: store_factory is a function or mapping
+            mall[store_name_for_var_name] = store_factory()
+
     if remove_save_name:
         rm_save_name = partial(rm_params, params_to_remove=[save_name_param])
     else:
@@ -429,6 +452,11 @@ def _crudified_funcs(
     yield from (fn.func for fn in func_nodes)
 
 
+def fnodes_to_var_node_crude_specs(fnodes):
+    for fnode in fnodes:
+        yield fnode.var, fnode.func, fnode.bind
+
+
 # empty_name_callback: Callable[[], Any] = None,
 # auto_namer: Callable[..., str] = None,
 # output_trans: Callable[..., Any] = None,
